@@ -1,7 +1,10 @@
+import logging
 import os, sys, errno
 from rpc import *
 import requests
 
+logger = logging.getLogger(__name__)
+
 if __name__ == '__main__':
     conf_arr = detect_cli_confs()
     available_conf_arr = []
